/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  GThumb
 *
 *  Copyright (C) 2004 Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#include <config.h>
#include <gnome.h>

static char *text[] = {
	N_("Previous"),
	N_("Next"),
	N_("Index"),
	N_("Image"),
	N_("Dimensions"),
	N_("Bytes"),
	N_("Date"),
	N_("Exposure time"),
	N_("Exposure mode"),
	N_("Flash"),
	N_("Shutter speed"),
	N_("Aperture value"),
	N_("Focal length"),
	N_("Camera model")
	N_("pixels")
}
